==> docs_mcp-0.1.0.tar.gz: docs_mcp-0.1.0/CONTRIBUTING.md <==
# docs-mcpへの貢献

docs-mcpへの貢献を歓迎します！以下のような形での貢献をお待ちしています：

> **Note**: 開発環境のセットアップ、テスト実行、リリース手順などの詳細については[DEVELOPMENT.md](DEVELOPMENT.md)をご覧ください。

- バグの報告
- コードに関する議論
- 修正の提出
- 新機能の提案
- メンテナになること

## GitHubを使った開発

GitHubを使用してコードのホスティング、issueと機能リクエストの追跡、プルリクエストの受け入れを行っています。

## [Github Flow](https://guides.github.com/introduction/flow/index.html)を使用しています

プルリクエストはコードベースへの変更を提案する最良の方法です。積極的にプルリクエストを歓迎します：

1. リポジトリをフォークし、`main`からブランチを作成します
2. テストが必要なコードを追加した場合は、テストを追加します
3. APIを変更した場合は、ドキュメントを更新します
4. テストスイートが合格することを確認します
5. コードが既存のスタイルに従っていることを確認します
6. プルリクエストを発行します！

## 貢献はMITソフトウェアライセンスの下で行われます

簡単に言うと、コードの変更を提出する際、あなたの提出物はプロジェクトをカバーする同じ[MITライセンス](LICENSE)の下にあることが理解されています。懸念がある場合は、メンテナに連絡してください。

## GitHubの[issues](https://github.com/herring101/docs-mcp/issues)を使ってバグを報告してください

GitHubのissueを使って公開バグを追跡しています。[新しいissueを開く](https://github.com/herring101/docs-mcp/issues/new)ことでバグを報告してください。とても簡単です！

## 詳細で背景とサンプルコードを含むバグレポートを書いてください

**優れたバグレポート**には以下が含まれる傾向があります：

- 簡潔な要約や背景
- 再現手順
  - 具体的に！
  - 可能であればサンプルコードを提供してください
- 期待される動作
- 実際の動作
- メモ（なぜこれが起こっていると思うか、試したがうまくいかなかったことなど）

## 開発プロセス

### 開発環境のセットアップ

1. リポジトリをクローン：
   ```bash
   git clone https://github.com/herring101/docs-mcp.git
   cd docs-mcp
   ```

2. uvを使って依存関係をインストール：
   ```bash
   uv sync
   ```

3. テストを実行して、すべてが正常に動作していることを確認：
   ```bash
   uv run pytest tests/
   ```

### コードスタイル

- Pythonコードのフォーマットとリントには[ruff](https://github.com/astral-sh/ruff)を使用しています
- PEP 8ガイドラインに従ってください
- 適切な場所で型ヒントを使用してください
- 関数は小さく、焦点を絞ったものにしてください
- 明確で自己文書化されたコードを書いてください

### テスト

- 新しい機能にはテストを書いてください
- PRを提出する前にすべてのテストが合格することを確認してください
- 良好なテストカバレッジを目指してください

### コミットメッセージ

- 明確で意味のあるコミットメッセージを使用してください
- 現在形の動詞で始めてください（例：「Add」、「Fix」、「Update」）
- 最初の行は50文字以内に収めてください
- 最初の行の後で、issueやプルリクエストを自由に参照してください

## ライセンス

貢献することで、あなたの貢献がMITライセンスの下でライセンスされることに同意します。

## 参考

このドキュメントは[Facebook's Draft](https://github.com/facebook/draft-js/blob/main/CONTRIBUTING.md)のオープンソース貢献ガイドラインから改変されました。

==> docs_mcp-0.1.1.tar.gz: docs_mcp-0.1.1/CONTRIBUTING.md <==
# docs-mcpへの貢献

docs-mcpへの貢献を歓迎します！以下のような形での貢献をお待ちしています：

> **Note**: 開発環境のセットアップ、テスト実行、リリース手順などの詳細については[DEVELOPMENT.md](DEVELOPMENT.md)をご覧ください。

- バグの報告
- コードに関する議論
- 修正の提出
- 新機能の提案
- メンテナになること

## GitHubを使った開発

GitHubを使用してコードのホスティング、issueと機能リクエストの追跡、プルリクエストの受け入れを行っています。

## [Github Flow](https://guides.github.com/introduction/flow/index.html)を使用しています

プルリクエストはコードベースへの変更を提案する最良の方法です。積極的にプルリクエストを歓迎します：

1. リポジトリをフォークし、`dev`からブランチを作成します
2. テストが必要なコードを追加した場合は、テストを追加します
3. APIを変更した場合は、ドキュメントを更新します
4. テストスイートが合格することを確認します
5. コードが既存のスタイルに従っていることを確認します
6. `dev`ブランチへプルリクエストを発行します！

### ブランチ戦略

- `main` - 本番ブランチ（直接のプッシュは禁止）
- `dev` - 開発ブランチ（全てのPRはここへ）
- `feature/*` - 新機能開発
- `fix/*` - バグ修正

開発フロー：
1. 全ての変更は`dev`ブランチへのPRとして提出
2. レビューとテスト後、`dev`にマージ
3. リリース準備ができたら、`dev`から`main`へのPRを作成

## 貢献はMITソフトウェアライセンスの下で行われます

簡単に言うと、コードの変更を提出する際、あなたの提出物はプロジェクトをカバーする同じ[MITライセンス](LICENSE)の下にあることが理解されています。懸念がある場合は、メンテナに連絡してください。

## GitHubの[issues](https://github.com/herring101/docs-mcp/issues)を使ってバグを報告してください

GitHubのissueを使って公開バグを追跡しています。[新しいissueを開く](https://github.com/herring101/docs-mcp/issues/new)ことでバグを報告してください。とても簡単です！

## 詳細で背景とサンプルコードを含むバグレポートを書いてください

**優れたバグレポート**には以下が含まれる傾向があります：

- 簡潔な要約や背景
- 再現手順
  - 具体的に！
  - 可能であればサンプルコードを提供してください
- 期待される動作
- 実際の動作
- メモ（なぜこれが起こっていると思うか、試したがうまくいかなかったことなど）

## 開発プロセス

### 開発環境のセットアップ

1. リポジトリをクローン：
   ```bash
   git clone https://github.com/herring101/docs-mcp.git
   cd docs-mcp
   ```

2. uvを使って依存関係をインストール：
   ```bash
   uv sync
   ```

3. テストを実行して、すべてが正常に動作していることを確認：
   ```bash
   uv run pytest tests/
   ```

### コードスタイル

- Pythonコードのフォーマットとリントには[ruff](https://github.com/astral-sh/ruff)を使用しています
- PEP 8ガイドラインに従ってください
- 適切な場所で型ヒントを使用してください
- 関数は小さく、焦点を絞ったものにしてください
- 明確で自己文書化されたコードを書いてください

### テスト

- 新しい機能にはテストを書いてください
- PRを提出する前にすべてのテストが合格することを確認してください
- 良好なテストカバレッジを目指してください

### コミットメッセージ

- 明確で意味のあるコミットメッセージを使用してください
- 現在形の動詞で始めてください（例：「Add」、「Fix」、「Update」）
- 最初の行は50文字以内に収めてください
- 最初の行の後で、issueやプルリクエストを自由に参照してください

## ライセンス

貢献することで、あなたの貢献がMITライセンスの下でライセンスされることに同意します。

## 参考

このドキュメントは[Facebook's Draft](https://github.com/facebook/draft-js/blob/main/CONTRIBUTING.md)のオープンソース貢献ガイドラインから改変されました。
